@@ -27,11 +27,12 @@ class FortniteAPI:
         The Shop endpoints. The class depends whether the api runs sync or async.
     """
 
-    def __init__(self, api_key: str, run_async: bool = False):
+    def __init__(self, api_key: str = None, run_async: bool = False):
         if type(api_key) is not str:
             raise TypeError('api_key require a value of type {0}'.format(str(str)))
         self.http = SyncHTTPClient() if not run_async else AsyncHTTPClient()
-        self.http.add_header('x-api-key', api_key)
+        if api_key:
+            self.http.add_header('x-api-key', api_key)
 
         self.aes = SyncAESEndpoints(self) if not run_async else AsyncAESEndpoints(self)
         self.cosmetics = SyncCosmeticsEndpoints(self) if not run_async else AsyncCosmeticsEndpoints(self)
